@@ -60,11 +60,13 @@ class AppArmor : public QObject {
     virtual bool isConfined(QString appId);
 
     static QString UNCONFINED_ID;
+    static QString LINUX_SECURITY_LABEL;
 
  private:
     void getSecurityDetails(const QString& connName,
                             SecurityDetails* details);
     QString getLocalPath(const QString& appId);
+    QString labelFromCredentials(const QVariantMap &map);
 
  private:
     const char* BASE_ACCOUNT_URL = "/com/lomiri/applications/%1";
