@@ -703,11 +703,11 @@ FileDownload::writeDataUri() {
     // file name + the mime type extension
     if (isBase64) {
         QByteArray encoded;
-        encoded.append(urlString);
+        encoded.append(urlString.toUtf8());
         data = QByteArray::fromBase64(encoded);
     } else {
         QByteArray encoded;
-        encoded.append(urlString);
+        encoded.append(urlString.toUtf8());
         data = QByteArray::fromPercentEncoding(encoded);
     }
 
